<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Read more</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go back</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Albums</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Folders</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bye</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
